==> humhub-1.13.1.tar.gz: humhub-1.13.1/protected/humhub/modules/admin/messages/it/information.php <==
<?php

return [
    '<strong>CronJob</strong> Status' => 'Stato <strong>Attività pianificate</strong>',
    '<strong>Queue</strong> Status' => 'Stato <strong>Attività in background</strong>',
    'About HumHub' => 'Informazioni su HumHub',
    'Assets' => 'Asset',
    'Background Jobs' => 'Attività in background',
    'Checking HumHub software prerequisites.' => 'Verifica i prerequisiti del software Humhub.',
    'Current limit is: {currentLimit}' => 'Il limite attuale è: {currentLimit}',
    'Database' => 'Database',
    'Database collation' => 'Collazione/Raccolta Database per verifica',
    'Database connection time: {dbTime} - Configured time zone: {time}' => 'Ora di connessione al database: {dbTime} - Fuso orario impostato: {time}',
    'Database driver - {driver}' => 'Driver database - {driver}',
    'Database migration results:' => 'Risultato della migrazione del database:',
    'Delayed' => 'Posticipato',
    'Displaying {count} entries per page.' => 'Mostra {count} elementi per pagina.',
    'Done' => 'Fatto',
    'Driver' => 'Driver',
    'Dynamic Config' => 'Configurazione dinamica',
    'Error' => 'Errore',
    'Flush entries' => 'Pulisci log',
    'HumHub is currently in debug mode. Disable it when running on production!' => 'HumHub è attualmente in modalità debug. Disabilitala nel momento in cui sarà in modalità produzione!',
    'ICU Data Version ({version})' => 'Versione dati ICU ({version}). (International Components for Unicode)',
    'ICU Data {icuMinVersion} or higher is required' => 'E\' richiesta una versione dati ICU {icuMinVersion} o successiva.',
    'ICU Version ({version})' => 'Versione ICU ({version})',
    'ICU {icuMinVersion} or higher is required' => 'E\' richiesta una versione ICU {icuMinVersion} o successiva.',
    'Increase memory limit in {fileName}' => 'Incrementa il limite della memoria in {fileName}',
    'Info' => 'Informazioni',
    'Install {phpExtension} Extension' => 'Installa Estensione {phpExtension}',
    'Install {phpExtension} Extension for APC Caching' => 'Installa Estensione {phpExtension} per APC Caching',
    'Install {phpExtension} Extension for DB Caching' => 'Installa Estensione {phpExtension} per DB Caching',
    'Install {phpExtension} Extension for e-mail S/MIME support.' => 'Installa Estensione {phpExtension} per supporto e-mail S/MIME.',
    'Last run (daily):' => 'Ultima esecuzione (giornaliera)',
    'Last run (hourly):' => 'Ultima esecuzione (oraria)',
    'Licences' => 'Licenze',
    'Logging' => 'Logging',
    'Make {filePath} writable for the Webserver/PHP!' => 'Rendi scrivibile {filePath} per il Webserver/PHP!',
    'Memory Limit ({memoryLimit})' => 'Limite di memoria ({memoryLimit})',
    'Minimum Version {minVersion}' => 'Versione minima {minVersion}',
    'Module Directory' => 'Elenco dei Moduli',
    'Multibyte String Functions' => 'Funzioni stringa multibyte',
    'Never' => 'Mai',
    'Optional' => 'Opzionale',
    'Other' => 'Altri',
    'Permissions' => 'Permessi',
    'Please refer to the documentation to setup the cronjobs and queue workers.' => 'Riferisciti alla documentazione per impostare le attività pianificate e quelle di background.',
    'Prerequisites' => 'Prerequisiti',
    'Profile Image' => 'Immagine di profilo',
    'Queue successfully cleared.' => 'Coda svuotata correttamente',
    'Re-Run tests' => 'Rilancia il test',
    'Recommended collation is {collation}' => 'La collazione/raccolta raccomandata è {collation}',
    'Recommended collation is {collation} for the tables: {tables}' => 'La collazione/raccolta raccomandata è {collation} per le tabelle: {tables}',
    'Recommended engine is {engine} for the tables: {tables}' => 'Il motore raccomandato è {engine} per le tabelle:  {tables}',
    'Reserved' => 'Riservato',
    'Runtime' => 'Runtime',
    'Search index rebuild in progress.' => 'Ricostruzione indice di ricerca in corso.',
    'Search term...' => 'Cerca termine...',
    'See installation manual for more details.' => 'Vedi manuale di installazione per ulteriori dettagli.',
    'Select category..' => 'Seleziona categoria...',
    'Select day' => 'Seleziona un giorno',
    'Select level...' => 'Seleziona livello...',
    'Settings' => 'Impostazioni',
    'Supported drivers: {drivers}' => 'Driver supportati: {drivers}',
    'Table collations' => 'Tabella Collazioni (raccolte)',
    'Table engines' => 'Tabella dei motori',
    'The current main HumHub database name is ' => 'Il database principale di Humhub si chiama:',
    'There is a new update available! (Latest version: %version%)' => 'Una nuova versione è disponibile! (Ultima versione: %version%)',
    'This HumHub installation is up to date!' => 'Questa installazione di HumHub è aggiornata!',
    'Time zone' => 'Fuso orario',
    'Total {count} entries found.' => '{count} elementi trovati in totale.',
    'Trace' => 'Traccia',
    'Uploads' => 'Caricamenti',
    'Varying table engines are not supported.' => 'I motori di tabelle variabili non sono supportati.',
    'Version' => 'Versione',
    'Waiting' => 'In attesa',
    'Warning' => 'Attenzione',
    '{imageExtension} Support' => 'Supporto {imageExtension}',
    '{phpExtension} Extension' => 'Estensione {phpExtension}',
    '{phpExtension} Support' => 'Supporto {phpExtension}',
    'Base URL' => '',
    'Detected URL: {currentBaseUrl}' => '',
    'HumHub' => '',
    'Marketplace API Connection' => '',
];

==> humhub-1.14.5.tar.gz: humhub-1.14.5/protected/humhub/modules/admin/messages/it/information.php <==
<?php

return [
    '<strong>CronJob</strong> Status' => 'Stato <strong>Attività pianificate</strong>',
    '<strong>Queue</strong> Status' => 'Stato <strong>Attività in background</strong>',
    'About HumHub' => 'Informazioni su HumHub',
    'Assets' => 'Asset',
    'Background Jobs' => 'Attività in background',
    'Base URL' => 'URL di base',
    'Checking HumHub software prerequisites.' => 'Verifica i prerequisiti del software Humhub.',
    'Current limit is: {currentLimit}' => 'Il limite attuale è: {currentLimit}',
    'Database' => 'Database',
    'Database collation' => 'Collazione/Raccolta Database per verifica',
    'Database connection time: {dbTime} - Configured time zone: {time}' => 'Ora di connessione al database: {dbTime} - Fuso orario impostato: {time}',
    'Database driver - {driver}' => 'Driver database - {driver}',
    'Database migration results:' => 'Risultato della migrazione del database:',
    'Delayed' => 'Posticipato',
    'Detected URL: {currentBaseUrl}' => 'URL rilevato:{currentBaseUrl}',
    'Displaying {count} entries per page.' => 'Mostra {count} elementi per pagina.',
    'Done' => 'Fatto',
    'Driver' => 'Driver',
    'Dynamic Config' => 'Configurazione dinamica',
    'Error' => 'Errore',
    'Flush entries' => 'Pulisci log',
    'HumHub' => 'HumHub',
    'HumHub is currently in debug mode. Disable it when running on production!' => 'HumHub è attualmente in modalità debug. Disabilitala nel momento in cui sarà in modalità produzione!',
    'ICU Data Version ({version})' => 'Versione dati ICU ({version}). (International Components for Unicode)',
    'ICU Data {icuMinVersion} or higher is required' => 'E\' richiesta una versione dati ICU {icuMinVersion} o successiva.',
    'ICU Version ({version})' => 'Versione ICU ({version})',
    'ICU {icuMinVersion} or higher is required' => 'E\' richiesta una versione ICU {icuMinVersion} o successiva.',
    'Increase memory limit in {fileName}' => 'Incrementa il limite della memoria in {fileName}',
    'Info' => 'Informazioni',
    'Install {phpExtension} Extension' => 'Installa Estensione {phpExtension}',
    'Install {phpExtension} Extension for APC Caching' => 'Installa Estensione {phpExtension} per APC Caching',
    'Install {phpExtension} Extension for DB Caching' => 'Installa Estensione {phpExtension} per DB Caching',
    'Install {phpExtension} Extension for e-mail S/MIME support.' => 'Installa Estensione {phpExtension} per supporto e-mail S/MIME.',
    'Last run (daily):' => 'Ultima esecuzione (giornaliera)',
    'Last run (hourly):' => 'Ultima esecuzione (oraria)',
    'Licences' => 'Licenze',
    'Logging' => 'Logging',
    'Make {filePath} writable for the Webserver/PHP!' => 'Rendi scrivibile {filePath} per il Webserver/PHP!',
    'Marketplace API Connection' => 'Connessione API del Marketplace',
    'Memory Limit ({memoryLimit})' => 'Limite di memoria ({memoryLimit})',
    'Minimum Version {minVersion}' => 'Versione minima {minVersion}',
    'Module Directory' => 'Elenco dei Moduli',
    'Multibyte String Functions' => 'Funzioni stringa multibyte',
    'Never' => 'Mai',
    'Optional' => 'Opzionale',
    'Other' => 'Altri',
    'Permissions' => 'Permessi',
    'Please refer to the documentation to setup the cronjobs and queue workers.' => 'Riferisciti alla documentazione per impostare le attività pianificate e quelle di background.',
    'Prerequisites' => 'Prerequisiti',
    'Profile Image' => 'Immagine di profilo',
    'Queue successfully cleared.' => 'Coda svuotata correttamente',
    'Re-Run tests' => 'Rilancia il test',
    'Recommended collation is {collation}' => 'La collazione/raccolta raccomandata è {collation}',
    'Recommended collation is {collation} for the tables: {tables}' => 'La collazione/raccolta raccomandata è {collation} per le tabelle: {tables}',
    'Recommended engine is {engine} for the tables: {tables}' => 'Il motore raccomandato è {engine} per le tabelle:  {tables}',
    'Reserved' => 'Riservato',
    'Runtime' => 'Runtime',
    'Search index rebuild in progress.' => 'Ricostruzione indice di ricerca in corso.',
    'Search term...' => 'Cerca termine...',
    'See installation manual for more details.' => 'Vedi manuale di installazione per ulteriori dettagli.',
    'Select category..' => 'Seleziona categoria...',
    'Select day' => 'Seleziona un giorno',
    'Select level...' => 'Seleziona livello...',
    'Settings' => 'Impostazioni',
    'Supported drivers: {drivers}' => 'Driver supportati: {drivers}',
    'Table collations' => 'Tabella Collazioni (raccolte)',
    'Table engines' => 'Tabella dei motori',
    'The current main HumHub database name is ' => 'Il database principale di Humhub si chiama:',
    'There is a new update available! (Latest version: %version%)' => 'Una nuova versione è disponibile! (Ultima versione: %version%)',
    'This HumHub installation is up to date!' => 'Questa installazione di HumHub è aggiornata!',
    'Time zone' => 'Fuso orario',
    'Total {count} entries found.' => '{count} elementi trovati in totale.',
    'Trace' => 'Traccia',
    'Uploads' => 'Caricamenti',
    'Varying table engines are not supported.' => 'I motori di tabelle variabili non sono supportati.',
    'Version' => 'Versione',
    'Waiting' => 'In attesa',
    'Warning' => 'Attenzione',
    '{imageExtension} Support' => 'Supporto {imageExtension}',
    '{phpExtension} Extension' => 'Estensione {phpExtension}',
    '{phpExtension} Support' => 'Supporto {phpExtension}',
    'Disabled Functions' => '',
    'HumHub Documentation' => '',
    'Make sure that the `proc_open` function is not disabled.' => '',
    'Pretty URLs' => '',
];
